@@ -19,13 +19,14 @@ from python_on_whales.utils import DockerCamelModel, ValidPath, run, to_list
 
 
 class VolumeInspectResult(DockerCamelModel):
-    created_at: datetime
-    driver: str
-    labels: Dict[str, str]
-    mountpoint: Path
     name: str
-    options: Optional[Dict[str, str]]
+    driver: str
+    mountpoint: Path
+    created_at: datetime
+    status: Optional[Dict[str, Any]]
+    labels: Dict[str, str]
     scope: str
+    options: Optional[Dict[str, str]]
 
 
 class Volume(ReloadableObjectFromJson):
@@ -34,6 +35,12 @@ class Volume(ReloadableObjectFromJson):
     ):
         super().__init__(client_config, "name", reference, is_immutable_id)
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.remove()
+
     def _fetch_inspect_result_json(self, reference):
         return run(self.docker_cmd + ["volume", "inspect", reference])
 
@@ -44,18 +51,34 @@ class Volume(ReloadableObjectFromJson):
     def name(self) -> str:
         return self._get_immutable_id()
 
-    @property
-    def created_at(self) -> datetime:
-        return self._get_inspect_result().created_at
-
     @property
     def driver(self) -> str:
         return self._get_inspect_result().driver
 
+    @property
+    def mountpoint(self) -> Path:
+        return self._get_inspect_result().mountpoint
+
+    @property
+    def created_at(self) -> datetime:
+        return self._get_inspect_result().created_at
+
+    @property
+    def status(self) -> Optional[Dict[str, Any]]:
+        return self._get_inspect_result().status
+
     @property
     def labels(self) -> Dict[str, str]:
         return self._get_inspect_result().labels
 
+    @property
+    def scope(self) -> str:
+        return self._get_inspect_result().scope
+
+    @property
+    def options(self) -> Optional[Dict[str, str]]:
+        return self._get_inspect_result().options
+
     def remove(self) -> None:
         """Removes this volume"""
         VolumeCLI(self.client_config).remove(self)
